# Selenium Chromedriver

[![PyPI version](https://badge.fury.io/py/selenium-chromedriver.svg)](https://badge.fury.io/py/selenium-chromedriver)

Install Stable version Chromedriver for Selenium on Windows, MacOS, M1 MacOS and Linux

## Usage

```sh
pip3 install selenium-chromedriver
python3 -m selenium-chromedriver
```